@@ -33,15 +33,18 @@ class AbstractComposite(Attributable, EventListener, Composite, DataWrapperMappe
 
         super().__init__(**kwds)
 
-    def toString(self, level=0, width=0,
-                 tablefmt='grid', tablefmt1='simple', tablefmt2='simple',
-                 extra=False, param_widths=None,
+    def toString(self, level=0, extra=False, param_widths=None,
+                 tablefmt='grid', tablefmt1='simple', tablefmt2='psql',
+                 width=0,
                  matprint=None, trans=True, beforedata='', heavy=True,
                  center=-1, **kwds):
         """ matprint: an external matrix print function
 
         Parameters
         ----------
+        level : int
+            Detailedness level.
+
         trans: print 2D matrix transposed. default is True.
         -------
 
@@ -53,8 +56,9 @@ class AbstractComposite(Attributable, EventListener, Composite, DataWrapperMappe
         if level > 1:
             s = f'{cn}('
             s += 'META: ' + mstr(self._meta, level=level, width=width,
-                                 tablefmt=tablefmt, tablefmt1=tablefmt1, tablefmt2=tablefmt2,
+                                 extra=extra,
                                  param_widths=param_widths,
+                                 tablefmt=tablefmt, tablefmt1=tablefmt1, tablefmt2=tablefmt2,
                                  excpt=['description'], **kwds)
             s += ' DATA: ' + mstr(self.data, level=level,
                                   excpt=['description'],
@@ -91,3 +95,4 @@ class AbstractComposite(Attributable, EventListener, Composite, DataWrapperMappe
         return '\n\n'.join((x for x in (s, beforedata, d) if len(x))) + '\n' + last
 
     string = toString
+    txt = toString
