@@ -15,8 +15,10 @@ except ImportError:
     Model = {'metadata': {}}
 import xmltodict
 
+import mmap
+
 import json
-import itertools
+from copy import copy
 from collections import OrderedDict
 import logging
 # create logger
@@ -43,15 +45,14 @@ class UnstructuredDataset(Dataset, Copyable):
         Accepts keyword args to `xmltodict`, e.g. `xml_attribs`, `attr_prefix` and `cdata_key`.
         """
 
-        self._list = []
-
         # collect MDPs from args-turned-local-variables.
-        metasToBeInstalled = OrderedDict(
-            itertools.filterfalse(
-                lambda x: x[0] in ('self', '__class__',
-                                   'data', 'zInfo', 'kwds'),
-                locals().items())
-        )
+        metasToBeInstalled = copy(locals())
+        metasToBeInstalled.pop('__class__', None)
+        metasToBeInstalled.pop('kwds', None)
+        metasToBeInstalled.pop('self', None)
+        metasToBeInstalled.pop('zInfo', None)
+
+        self._list = []
 
         global Model
         if zInfo is None:
@@ -97,6 +98,8 @@ class UnstructuredDataset(Dataset, Copyable):
             stid = b'_STID' if issubclass(data.__class__, bytes) else '_STID'
             # do not ask for self.type unless there is real data.
             if self.doctype == 'json':
+                if issubclass(data.__class__, mmap.mmap):
+                    data = bytearray(data)
                 loaded = json.loads(data, **kwds)
             elif self.doctype == 'xml':
                 xa = kwds.pop('xml_attribs', None)
