@@ -2,12 +2,13 @@
 from ..pns.fdi_requests import save_to_server, read_from_server, delete_from_server, post_to_server
 from ..dataset.serializable import serialize
 from ..dataset.deserialize import deserialize, serialize_args
+from ..dataset.classes import All_Exceptions
 from .poolmanager import PoolManager
 from .productref import ProductRef
 from .productpool import ProductPool
 from ..httppool.session import requests_retry_session
 
-from .dicthk import HKDBS
+from .dicthk import HKDBS, get_missing
 from ..utils.common import trbk, lls, fullname
 from .urn import Urn, makeUrn
 
@@ -35,9 +36,6 @@ def writeJsonwithbackup(fp, data):
         f.write(js)
 
 
-bltn = vars(builtins)
-
-
 def toserver(self, method, *args, **kwds):
     # if method == 'select':
     #    __import__('pdb').set_trace()
@@ -58,11 +56,12 @@ def toserver(self, method, *args, **kwds):
     if issubclass(res.__class__, str) and 'FAILED' in res or code != 200:
         for line in chain(msg.split('.', 1)[:1], msg.split('\n')):
             excpt = line.split(':', 1)[0]
-            if excpt in bltn:
+            if excpt in All_Exceptions:
                 # relay the exception from server
-                raise bltn[excpt](('Code %d: %s' % (code, msg)))
-        raise RuntimeError('Executing ' + method +
-                           ' failed. Code: %d Message: %s' % (code, msg))
+                raise All_Exceptions[excpt](
+                    (f'SERVER: Code {code} Message: {msg}'))
+        raise RuntimeError(
+            f'Executing {method} failed. SERVER: Code {code} Message: {msg}')
     return res
 
 
@@ -127,6 +126,8 @@ class HttpClientPool(ProductPool):
 
         return False
 
+    get_missing = get_missing
+
     # @toServer()
     def readHK(self):
         """
@@ -152,7 +153,7 @@ class HttpClientPool(ProductPool):
             raise Exception(msg)
         return hk
 
-    def schematicSave(self, products, tag=None, geturnobjs=False, serialize_out=False, **kwds):
+    def schematicSave(self, products, tag=None, geturnobjs=False, serialize_out=False, asyn=False, **kwds):
         """
         does the media-specific saving to remote server.
         """
@@ -228,35 +229,40 @@ class HttpClientPool(ProductPool):
             raise NameError('Loading ' + urn + ' failed:%d. ' % code + msg)
         return res
 
-    def schematicRemove(self, urn=None, resourcetype=None, index=None):
+    def schematicRemove(self, urn=None, resourcetype=None, index=None, asyn=False, **kwds):
         """
         does the scheme-specific part of removal.
 
         urn or (resourcetype, index)
         """
-        if urn is None:
-            if resourcetype is None or index is None:
-                raise ValueError()
-            urn = makeUrn(self._poolname, resourcetype, index)
+        urn, datatype, sn = self.get_missing(
+            urn, resourcetype, index, no_check=True)
         res, msg = delete_from_server(
-            urn, self._poolurl, auth=self.auth, client=self.client)
+            urn, self._poolurl, auth=self.auth, client=self.client,
+            asyn=asyn, **kwds)
         if res == 'FAILED':
-            logger.error('Remove from server ' + self._poolname +
-                         ' failed. Caused by: ' + msg)
-            raise RuntimeError(msg)
+            msg = 'Remove from server ' + self._poolname +\
+                ' failed. Caused by: ' + msg
+            if getattr(self, 'ignore_error_when_delete', False):
+                logger.warning(msg)
+            else:
+                raise RuntimeError(msg)
         return 0
 
-    def schematicWipe(self):
+    def doWipe(self):
         """
-        does the scheme-specific remove-all
+        does the scheme-specific wiping.
         """
 
         res, msg = delete_from_server(
-            None, self._poolurl, 'pool', client=self.client)
+            None, self._poolurl, 'pool', client=self.client,
+            asyn=asyn, **kwds)
         if res == 'FAILED':
-            logger.error(msg)
-            raise Exception(msg)
-        return 0
+            if getattr(self, 'ignore_error_when_delete', False):
+                logger.warning(msg)
+            else:
+                raise Exception(msg)
+        return res
 
     @ toServer()
     def removeAll(self):
@@ -289,6 +295,13 @@ class HttpClientPool(ProductPool):
 
         # return self.toserver('exists', urn)
 
+    @ toServer()
+    def getAllUrns(self):
+        """
+        Return all URNs in the remote pool.
+        """
+        raise NotImplementedError
+
     @ toServer()
     def getPoolpath(self):
         """
