@@ -67,23 +67,26 @@ def remoteRegister(pool):
                 'Registering ' + poolurl + ' failed with auth ' + np + ' , ' + msg)
         return res, msg
     elif issubclass(pool.__class__, publicclientpool.PublicClientPool):
-
+        from ..pns.fdi_requests import ServerError
         # register csdb pool. If existing, load. IF not exists, create and initialize sn.
-        status, poolres = pool.createPool2()
+        poolurl = pool._poolurl
+        try:
+            res = pool.createPool2()
 
-        if status:
             pool.getToken()
             pool.client.headers.update({'X-AUTH-TOKEN': pool.token})
-            if poolres['code'] == 1:
-                # exists
-                pinfo = pool.getPoolInfo()
+            msg = 'New pool made.'
+            pool.poolInfo = pool.getPoolInfo()
             res = 'OK'
-        elif not status:
-            msg = poolres['msg']
+        except ServerError as e:
+            # if e.code == 1:
+            #   msg = 'Pool exists or bad namw.'
+            msg = str(e)
             logger.error(
                 'Registering ' + poolurl + ' failed with auth ' + 'np' + ' , ' + msg)
             res = 'FAILED'
-        return res, poolres['msg']
+            raise
+        return res, msg
     else:
         return
 
@@ -110,9 +113,9 @@ def remoteUnregister(poolurl, auth=None, client=None):
         raise NameError(
             f'Remote Unregistering failed. {poolurl} not registered or not suitable.')
     from ..pns.fdi_requests import delete_from_server
-    #url = api_baseurl + post_poolid
-    #x = requests.delete(url, auth=HTTPBasicAuth(auth_user, auth_pass))
-    #o = deserialize(x.text)
+    # url = api_baseurl + post_poolid
+    # x = requests.delete(url, auth=HTTPBasicAuth(auth_user, auth_pass))
+    # o = deserialize(x.text)
     urn = 'urn:::0'
     try:
         res, msg = delete_from_server(
@@ -120,9 +123,12 @@ def remoteUnregister(poolurl, auth=None, client=None):
     except ConnectionError as e:
         res, msg = 'FAILED', str(e)
     if res == 'FAILED':
-        logger.warning('Ignored: Unregistering ' +
-                       poolurl + ' failed.  ' + msg)
-        code = 2
+        msg = f'Unregistering {poolurl} failed. {msg}'
+        if getattr(poolo, 'ignore_error_when_delete', False):
+            logger.info('Ignored: ' + msg)
+            code = 2
+        else:
+            raise ValueError(msg)
     else:
         code = 0
     return code
@@ -263,9 +269,9 @@ Pools registered are kept as long as the last reference remains. When the last i
                 res, msg = remoteRegister(p)
             else:
                 raise NotImplementedError(schm + ':// is not supported')
-        #print(getweakrefs(p), id(p), '////')
+        # print(getweakrefs(p), id(p), '////')
         cls.save(poolname, p)
-        #print(getweakrefs(p), id(p))
+        # print(getweakrefs(p), id(p))
 
         # Pass poolurl to PoolManager.remove() for remote pools
         # finalize(p, print, poolname, poolurl)
