@@ -10,7 +10,12 @@ from .versionable import Versionable
 from .taggable import Taggable
 from . import dicthk
 from .definable import Definable
-from ..utils.common import pathjoin, fullname, lls, trbk
+from ..utils.common import (fullname, lls, trbk, pathjoin,
+                            logging_ERROR,
+                            logging_WARNING,
+                            logging_INFO,
+                            logging_DEBUG
+                            )
 from .productref import ProductRef
 from .query import AbstractQuery, MetaQuery, StorageQuery
 
@@ -82,6 +87,7 @@ When implementing a ProductPool, the following rules need to be applied:
         # self._pathurl = pr.netloc + pr.path
         # self._pathurl = None
         self._poolmanager = None
+        self.ignore_error_when_delete = False
 
     class ParametersIncommpleteError(Exception):
         pass
@@ -239,6 +245,36 @@ When implementing a ProductPool, the following rules need to be applied:
         """
         return self.getId()
 
+    @staticmethod
+    def vectorize(*p):
+        """
+      ::
+        vectorize(9, [8,7,6]) -> ([9, 9, 9], [8, 7,  6], True)
+        """
+
+        lens = [len(v) if isinstance(v, (list, tuple)) else 0 for v in p]
+
+        sz = max(lens)
+        # remove redundant
+        s = set(lens)
+        alist = any(s)
+        # remove longest and scalar
+        s.remove(sz)
+        try:
+            s.remove(0)
+        except KeyError:
+            pass
+        if len(s):
+            # found more than 2 sizes
+            raise ValueError(f'Some args have different sizes {s}.')
+        if sz == 0:
+            # force scalar  to vector
+            sz = 1
+
+        res = [q if l else ([q] * sz) for q, l in zip(p, lens)]
+        res.append(alist)
+        return tuple(res)
+
     def isAlive(self):
         """
         Test if the pool is capable of responding to commands.
@@ -252,14 +288,14 @@ When implementing a ProductPool, the following rules need to be applied:
 
         raise NotImplementedError
 
-    def schematicSave(self, products, tag=None, geturnobjs=False, serialize_in=True, serialize_out=False, **kwds):
+    def schematicSave(self, products, tag=None, geturnobjs=False, serialize_in=True, serialize_out=False, asyn=False, **kwds):
         """ to be implemented by subclasses to do the scheme-specific saving
         """
         raise (NotImplementedError)
 
-    def saveProduct(self, product, tag=None, geturnobjs=False, serialize_in=True, serialize_out=False, **kwds):
+    def saveProduct(self, product, tag=None, geturnobjs=False, serialize_in=True, serialize_out=False, asyn=False, **kwds):
         """
-        Saves specified product and returns the designated ProductRefs or URNs.
+        Saves specified product(s) and returns the designated ProductRefs or URNs.
 
         Saves a product or a list of products to the pool, possibly under the
         supplied tag(s), and returns the reference (or a list of references if
@@ -267,15 +303,28 @@ When implementing a ProductPool, the following rules need to be applied:
 
         See pal document for pool structure.
 
+        Parameters
+        ----------
+        product : BaseProduct, list
+            Product or a list of them or '[ size1, prd, size2, prd2, ...]'.
+        tag : str, list
+            If given a tag, all products will be having this tag.
+        If a list tags are given to every one product then the
+        number of tags must not be the same to that of `product`. If
+        they are equal, each tag is goven to the product at the same
+        index in the `product` list.
+        serialize_out : bool
+            if `True` returns contents in serialized form.
+        serialize_in : bool
+            If set, product input is serialized.
 
-        tag: a tag if given as a string type; a list of tags if given a list.
-        serialize_out: if True returns contents in serialized form.
         """
 
         res = self.schematicSave(product, tag=tag,
                                  geturnobjs=geturnobjs,
                                  serialize_in=serialize_in,
-                                 serialize_out=serialize_out, **kwds)
+                                 serialize_out=serialize_out,
+                                 asyn=asyn, **kwds)
         if issubclass(product.__class__, str) or isinstance(product, list) and \
            issubclass(product[0].__class__, str):
             # p is urn string from server-side LocalPool
@@ -301,7 +350,7 @@ When implementing a ProductPool, the following rules need to be applied:
         """
         raise (NotImplementedError)
 
-    def loadProduct(self, urn, serialize_out=False):
+    def loadProduct(self, urn, serialize_out=False, asyn=False):
         """
         Loads a Product belonging to specified URN.
 
@@ -361,18 +410,18 @@ When implementing a ProductPool, the following rules need to be applied:
 
         raise (NotImplementedError)
 
-    def schematicRemove(self, urn=None, resourcetype=None, index=None):
+    def schematicRemove(self, urn=None, resourcetype=None, index=None, asyn=False, **kwds):
         """ to be implemented by subclasses to do the scheme-specific removing
         """
         raise (NotImplementedError)
 
-    def remove(self, urn=None, resourcetype=None, index=None,
-               ignore_error=False):
+    def remove(self, urn=None, resourcetype=None, index=None, ignore_error=False, asyn=False, **kwds):
         """
         Removes a Product belonging to specified URN or a pair of data type and serial number.
         """
         self.ignore_error_when_delete = ignore_error
-        res = self.schematicRemove(urn, resourcetype=resourcetype, index=index)
+        res = self.schematicRemove(
+            urn, resourcetype=resourcetype, index=index, asyn=asyn, **kwds)
         return res
 
     def schematicWipe(self):
@@ -380,14 +429,14 @@ When implementing a ProductPool, the following rules need to be applied:
         """
         raise (NotImplementedError)
 
-    def removeAll(self, ignore_error=False):
+    def removeAll(self, ignore_error=False, asyn=False, **kwds):
         """
         Remove all pool data (self, products) and all pool meta data (self, descriptors, indices, etc.).
         """
         self.ignore_error_when_delete = ignore_error
-        return self.schematicWipe()
+        return self.schematicWipe(asyn=asyn, **kwds)
 
-    def saveDescriptors(self,  urn,  desc):
+    def saveDescriptors(self, urn, desc):
         """
         Save/Update descriptors in pool.
         """
@@ -485,13 +534,14 @@ def _eval(code='', m='', **kwds):
     return res
 
 
-def populate_pool2(tags, pn, dTypes=None, dTags=None):
+def populate_pool2(tags, ptype, sn=None, dTypes=None, dTags=None):
     """
     tags : list
-        The tags in a list.
-    pn : str
+        The tags in a list. `None` and empty tags are ignored.
+    ptype : str
         The product name / datatype / class name of the data item, new or existing.
-
+    sn : str
+        Serial number. If is `None`, use the one in `dTypes`.
     Returns
     -------
     tuple
@@ -504,16 +554,19 @@ def populate_pool2(tags, pn, dTypes=None, dTags=None):
     if dTags is None:
         dTags = {}
 
-    if pn in dTypes:
-        int_sn = dTypes[pn]['currentSN'] + 1
+    if ptype in dTypes:
+        if sn is None:
+            int_sn = dTypes[ptype]['currentSN'] + 1
+        else:
+            int_sn = int(sn)
     else:
-        int_sn = 0
-        dTypes[pn] = {
+        int_sn = 0 if sn is None else int(sn)
+        dTypes[ptype] = {
             'currentSN': int_sn,
             'sn': {}
         }
 
-    snd = dTypes[pn]['sn']
+    snd = dTypes[ptype]['sn']
     _sn = str(int_sn)
     if int_sn not in snd:
         snd[int_sn] = {
@@ -521,11 +574,12 @@ def populate_pool2(tags, pn, dTypes=None, dTags=None):
             'meta': []
         }
 
-    dTypes[pn]['currentSN'] = int_sn
+    dTypes[ptype]['currentSN'] = int_sn
 
     # /new #####
-    for t in tags:
-        dicthk.add_tag_datatype_sn(t, pn, int_sn, dTypes, dTags)
+    if tags is not None:
+        for t in tags:
+            dicthk.add_tag_datatype_sn(t, ptype, int_sn, dTypes, dTags)
 
     return dTypes, dTags, _sn
 
@@ -625,7 +679,8 @@ class ManagedPool(ProductPool, dicthk.DictHk):
         """
         # new ###
         try:
-            urn, datatype, sn = self.get_missing(urn, resourcetype, index)
+            urn, datatype, sn = self.get_missing(
+                urn, resourcetype, index, no_check=True)
         except KeyError:
             return False
         # return True
@@ -692,6 +747,19 @@ class ManagedPool(ProductPool, dicthk.DictHk):
         return self._dTypes
         # return self._urns[urn]
 
+    def readHK():
+        """ Subclass should overide this.
+
+        Returns
+        -------
+        tuple
+          Of 5 dicts that are the legacy `self._classes`, `self._tags`,
+           `self._urns`, and
+                    `self._dTypes`, `self._dTags`
+
+        """
+        raise NotImplementedError()
+
     def setMetaByUrn(self, start, end, urn=None, datatype=None, sn=None):
         """
         Sets the location of the meta data of the specified data to the given URN or a pair of data type and serial number.
@@ -704,7 +772,7 @@ class ManagedPool(ProductPool, dicthk.DictHk):
         :sn: serial number in string.
         """
 
-        raise NotImplemented
+        raise NotImplementedError()
 
     def getMetaByUrn(self, urn=None, resourcetype=None, index=None):
         """
@@ -729,7 +797,7 @@ class ManagedPool(ProductPool, dicthk.DictHk):
         _snd = self._dType[dt]['sn'][sn]
         if 'refcnt' not in _snd:
             _snd['refcnt'] = 0
-        ####assert self._urns[ref.urn]['refcnt'] == _snd['refcnt']
+        # assert self._urns[ref.urn]['refcnt'] == _snd['refcnt']
         _snd['refcnt'] += 1
         # /new ###
         if 0:
@@ -737,7 +805,7 @@ class ManagedPool(ProductPool, dicthk.DictHk):
                 self._urns['refcnt'] = 0
             self._urns[ref.urn]['refcnt'] += 1
 
-    def saveOne(self, prd, tag, geturnobjs, serialize_in, serialize_out, res, kwds):
+    def saveOne(self, prd, tag, geturnobjs, serialize_in, serialize_out, res, **kwds):
         """
         Save one product.
 
@@ -782,7 +850,7 @@ class ManagedPool(ProductPool, dicthk.DictHk):
                      'white': { 'foo.bar.Bar'; [0, 1] }
                      'dog': ...
 
-        :res: list of result.
+        :res: list of results.
         :serialize_out: if True returns contents in serialized form.
 
         Return
@@ -807,24 +875,24 @@ class ManagedPool(ProductPool, dicthk.DictHk):
                 self._dTypes, self._dTags = tuple(
                     self.readHK().values())
             # /some new ####
-            if 0:
-                c, t, u = self._classes, self._tags, self._urns
+            # if 0:
+            #     c, t, u = self._classes, self._tags, self._urns
 
-                if pn in c:
-                    sn = (c[pn]['currentSN'] + 1)
-                else:
-                    sn = 0
-                    c[pn] = dict(sn=[])
+            #     if pn in c:
+            #         sn = (c[pn]['currentSN'] + 1)
+            #     else:
+            #         sn = 0
+            #         c[pn] = dict(sn=[])
 
-                c[pn]['currentSN'] = sn
-                c[pn]['sn'].append(sn)
+            #     c[pn]['currentSN'] = sn
+            #     c[pn]['sn'].append(sn)
 
-                urn = makeUrn(poolname=self._poolname, typename=pn, index=sn)
+            #     urn = makeUrn(poolname=self._poolname, typename=pn, index=sn)
 
-                if urn not in u:
-                    u[urn] = {'tags': []}
+            #     if urn not in u:
+            #         u[urn] = {'tags': []}
 
-            # new+old ###
+            # new+old NORMALIZE TAGS###
             if tag is None:
                 tags = []
             elif issubclass(tag.__class__, str):
@@ -835,45 +903,45 @@ class ManagedPool(ProductPool, dicthk.DictHk):
                 raise TypeError('Bad type for tag: %s.' %
                                 tag.__class__.__name__)
             # new ####
-            self._dTypes, self._dTags, _sn = populate_pool2(tags, pn,
-                                                            self._dTypes,
-                                                            self._dTags)
+            self._dTypes, self._dTags, _sn = \
+                populate_pool2(tags, pn, sn=None,
+                               dTypes=self._dTypes, dTags=self._dTags)
 
-            if 0:
-                if tag is None:
-                    tags = []
-                elif issubclass(tag.__class__, str):
-                    tags = [tag]
-                elif issubclass(tag.__class__, list):
-                    tags = tag
-                else:
-                    raise TypeError('Bad type for tag: %s.' %
-                                    tag.__class__.__name__)
-                # new ####
-                dTypes, dTags = self._dTypes, self._dTags
+            # if 0:
+            #     if tag is None:
+            #         tags = []
+            #     elif issubclass(tag.__class__, str):
+            #         tags = [tag]
+            #     elif issubclass(tag.__class__, list):
+            #         tags = tag
+            #     else:
+            #         raise TypeError('Bad type for tag: %s.' %
+            #                         tag.__class__.__name__)
+            #     # new ####
+            #     dTypes, dTags = self._dTypes, self._dTags
 
-                if pn in dTypes:
-                    _sn = dTypes[pn]['currentSN'] + 1
-                else:
-                    _sn = 0
-                    dTypes[pn] = {
-                        'currentSN': _sn,
-                        'sn': {}
-                    }
+            #     if pn in dTypes:
+            #         _sn = dTypes[pn]['currentSN'] + 1
+            #     else:
+            #         _sn = 0
+            #         dTypes[pn] = {
+            #             'currentSN': _sn,
+            #             'sn': {}
+            #         }
 
-                snd = dTypes[pn]['sn']
-                if _sn not in snd:
-                    snd[_sn] = {
-                        'tags': [],
-                        'meta': []
-                    }
+            #     snd = dTypes[pn]['sn']
+            #     if _sn not in snd:
+            #         snd[_sn] = {
+            #             'tags': [],
+            #             'meta': []
+            #         }
 
-                dTypes[pn]['currentSN'] = _sn
-                urn = makeUrn(poolname=self._poolname, typename=pn, index=_sn)
-                # /new #####
+            #     dTypes[pn]['currentSN'] = _sn
+            #     urn = makeUrn(poolname=self._poolname, typename=pn, index=_sn)
+            #     # /new #####
 
-                for t in tags:
-                    self.setTag(t, urn)
+            #     for t in tags:
+            #         self.setTag(t, urn)
             urn = makeUrn(poolname=self._poolname, typename=pn, index=_sn)
             try:
                 # save prod and HK
@@ -910,37 +978,66 @@ class ManagedPool(ProductPool, dicthk.DictHk):
                 rf._meta = prd.getMeta()
                 res.append(rf)
 
-    def schematicSave(self, products, tag=None, geturnobjs=False, serialize_in=True, serialize_out=False, **kwds):
+    def schematicSave(self, products, tag=None, geturnobjs=False, serialize_in=True, serialize_out=False, asyn=False, **kwds):
         """ do the scheme-specific saving.
-        :product:  product or '[ size1, prd, size2, prd2, ...]'.
-        :serialize_out: if True returns contents in serialized form.
-        :serialize_in: if set, product input is seriaized.
 
-        Return
-        ------
-        `ProductRef`. `Urn` if `geturnobjs` is set. If `serialze_out` is set `str` of serialized form of `ProductRef` or `URN`.
+        Parameters
+        ----------
+        product : BaseProduct, list
+            Product or a list of them or '[ size1, prd, size2, prd2, ...]'.
+        tag : str, list
+            If given a tag, all products will be having this tag.
+        If a list tags are given to every one product then the
+        number of tags must not be the same to that of `product`. If
+        they are equal, each tag is goven to the product at the same
+        index in the `product` list.
+        serialize_out : bool
+            if `True` returns contents in serialized form.
+        serialize_in : bool
+            If set, product input is serialized.
 
-        `list` of the above of input is a list.
+        Returns
+        -------
+        ProductRef: Product reference.
+        Urn: If `geturnobjs` is set.
+        str: If `serialze_out` is set, serialized form of `ProductRef` or `URN`.
+        list: `list` of the above of input is a list.
         """
+
         res = []
+        alist = issubclass(products.__class__, list)
+        json_list = False
+
+        if alist:
+            if isinstance(tag, list) and len(tag) != len(products):
+                # make a list of tags to ','-separated tags
+                tag = ','.join(t for t in tag if t)
+            if isinstance(tag, str) or tag is None:
+                tag = [tag] * len(products)
 
         if serialize_in:
-            alist = issubclass(products.__class__, list)
             if not alist:
                 prd = products
                 self.saveOne(prd, tag, geturnobjs,
-                             serialize_in, serialize_out, res, kwds)
+                             serialize_in, serialize_out, res, **kwds)
             else:
-                for prd in products:
-                    # result is in res
-                    self.saveOne(prd, tag, geturnobjs,
-                                 serialize_in, serialize_out, res, kwds)
+                if asyn:
+                    prd = products
+                    self.asyncSave(prd, tag, geturnobjs,
+                                   serialize_in, serialize_out, res, **kwds)
+                else:
+                    for prd, t in zip(products, tag):
+                        # result is in res
+                        self.saveOne(prd, t, geturnobjs,
+                                     serialize_in, serialize_out, res, **kwds)
         else:
-            alist = products.lstrip().startswith('[')
-            if not alist:
+            if alist:
+                raise TypeError('a list cannot go with False serialize-in.')
+            json_list = products.lstrip().startswith('[')
+            if not json_list:
                 prd = products
                 self.saveOne(prd, tag, geturnobjs,
-                             serialize_in, serialize_out, res, kwds)
+                             serialize_in, serialize_out, res, **kwds)
             else:
                 # parse '[ size1, prd, size2, prd2, ...]'
 
@@ -953,15 +1050,16 @@ class ManagedPool(ProductPool, dicthk.DictHk):
                     last_end = comma + 1 + length
                     prd = products[comma + 2: last_end+1]
                     self.saveOne(prd, tag, geturnobjs,
-                                 serialize_in, serialize_out, res, kwds)
+                                 serialize_in, serialize_out, res, **kwds)
                     # +2 to skip the following ', '
                     last_end += 2
                     comma = products.find(',', last_end)
-        sz = 1 if not alist else len(
-            products) if serialize_in else len(productlist)
-        logger.debug('%d product(s) generated %d %s: %s.' %
-                     (sz, len(res), 'Urns ' if geturnobjs else 'prodRefs', lls(res, 200)))
-        if alist:
+        if logger.isEnabledFor(logging_DEBUG):
+            sz = 1 if not json_list and not alist else len(
+                products) if serialize_in else len(productlist)
+            logger.debug('%d product(s) generated %d %s: %s.' %
+                         (sz, len(res), 'Urns ' if geturnobjs else 'prodRefs', lls(res, 200)))
+        if alist or json_list:
             return serialize(res) if serialize_out else res
         else:
             return serialize(res[0]) if serialize_out else res[0]
@@ -982,16 +1080,17 @@ class ManagedPool(ProductPool, dicthk.DictHk):
                               serialize_out=serialize_out)
         return ret
 
-    def doRemove(self, resourcetype, index):
+    def doRemove(self, resourcetype, index, ayn=False):
         """ to be implemented by subclasses to do the action of reemoving
         """
         raise (NotImplementedError)
 
-    def schematicRemove(self, urn=None, resourcetype=None, index=None):
+    def schematicRemove(self, urn=None, resourcetype=None, index=None, asyn=False, **kwds):
         """ do the scheme-specific removing
         """
 
-        urn, datatype, sn = self.get_missing(urn, resourcetype, index)
+        urn, datatype, sn = self.get_missing(
+            urn, resourcetype, index, no_check=True)
 
         with filelock.FileLock(self.lockpath('w')),\
                 filelock.FileLock(self.lockpath('r')):
@@ -1001,71 +1100,75 @@ class ManagedPool(ProductPool, dicthk.DictHk):
             self._classes, self._tags, self._urns, \
                 self._dTypes, self._dTags = tuple(
                     self.readHK().values())
-            if 0:
-                c, t, u = self._classes, self._tags, self._urns
-                if urn not in u:
-                    raise ValueError(
-                        '%s not found in pool %s.' % (urn, self.getId()))
-
-            # new ####
-            dTypes, dTags = self._dTypes, self._dTags
-
-            if sn not in dTypes[datatype]['sn']:
-                raise ValueError(
-                    '%d not found in pool %s.' % (sn, self.getId()))
-            # /new ####
+            # c, t, u = self._classes, self._tags, self._urns
+            # if urn not in u:
+            #     raise ValueError(
+            #         '%s not found in pool %s.' % (urn, self.getId()))
+            datatypes, sns, alist = ProductPool.vectorize(datatype, sn)
 
             self.removeUrn(urn, datatype=datatype, sn=sn)
 
-            if 0:
-                c[datatype]['sn'].remove(sn)
+        if 0:
+            n = max(lr, li)
+            if lr and li and lr != li:
+                raise TypeError(
+                    f'Two args have different sizes {lr}, {li}.')
+            alist = lr or li
+            if n == 0:
+                n = 1
+            datatypes = datatype if lr else [datatype] * n
+            sns = sn if li else [sn] * n
 
-                if len(c[datatype]['sn']) == 0:
-                    del c[datatype]
-            # new ####
-            if len(dTypes[datatype]['sn']) == 0:
-                del dTypes[datatype]
-            else:
-                ####assert list(dTypes[datatype]['sn']) == list(c[datatype]['sn'])
-                pass
-            # /new ####
-            try:
-                self.doRemove(resourcetype=datatype, index=sn)
-            except Exception as e:
-                msg = 'product ' + urn + ' removal failed'
-                logger.debug(msg)
-                self._classes, self._tags, self._urns, \
-                    self._dTypes, self._dTags = tuple(
-                        self.readHK().values())
-                raise e
-        return 0
+        res = self.doRemove(resourcetype=datatypes, index=sns, asyn=asyn)
+
+        res1 = res if alist else [res]
+        for i, r in enumerate(res1):
+            if r is None:
+                msg = f'product {urn[i]} removal failed.'
+                if isinstance(self, (LocalPool, MemPool, HTTPClientpool)):
+                    self._classes, self._tags, self._urns, \
+                        self._dTypes, self._dTags = tuple(
+                            self.readHK().values())
+                    if getattr(self, 'ignore_error_when_delete', False):
+                        raise
+                    else:
+                        logger.warning(msg)
+
+                    # can only do one at a time
+                    break
+                elif isinstance(self, (PublicClientPool)):
+                    self.getPoolInfo(update_hk=True)
+        return res if alist else res[0]
 
     def doWipe(self):
         """ to be implemented by subclasses to do the action of wiping.
         """
         raise (NotImplementedError)
 
-    def schematicWipe(self):
+    def schematicWipe(self, asyn=False):
         """ do the scheme-specific wiping
         """
         with filelock.FileLock(self.lockpath('w')),\
                 filelock.FileLock(self.lockpath('r')):
-            try:
-                if 0:
-                    self._classes.clear()
-                    self._tags.clear()
-                    self._urns.clear()
-                # new ##
-                self._dTypes.clear()
-                self._dTags.clear()
-                # /new ##
-                self.doWipe()
-            except Exception as e:
-                msg = self.getId() + 'wiping failed'
-                logger.debug(msg)
-                raise e
-        logger.debug('Done.')
-        return 0
+            # self._classes.clear()
+            # self._tags.clear()
+            # self._urns.clear()
+            # new ##
+            self._dTypes.clear()
+            self._dTags.clear()
+            # /new ##
+            if asyn:
+                res = self.doAsyncWipe()
+            else:
+                try:
+                    res = self.doWipe()
+                except ValueError as e:
+                    msg = f'Wiping {self.poolname} failed. {e} traceback: {trbk(e)}'
+                    if getattr(self, 'ignore_error_when_delete', False):
+                        logger.warning(msg)
+                    else:
+                        raise
+        return res
 
     def meta_filter(self, q, typename=None, reflist=None, urnlist=None, snlist=None, datatypes=None):
         """ returns filtered collection using the query.
@@ -1254,7 +1357,7 @@ class ManagedPool(ProductPool, dicthk.DictHk):
         # new ###
         res2 = self.prod_filter(q, prod, datatypes=datatypes)
 
-        #### assert [r.urn for r in res] == [r.urn for r in res2]
+        # assert [r.urn for r in res] == [r.urn for r in res2]
         return [r.urn for r in res2]
 
     def doSelect(self, query, previous=None):
@@ -1284,13 +1387,13 @@ class ManagedPool(ProductPool, dicthk.DictHk):
                 ret += self.prod_filter(q=query, reflist=this)
         else:
             # new ##
-            #### assert list(self._dTypes) == list(self._classes)
+            # assert list(self._dTypes) == list(self._classes)
             for cname in self._dTypes:
                 cls = lgb[cname.rsplit('.', 1)[-1]]
                 if issubclass(cls, t):
-                    ###snlist = self._classes[cname]['sn']
+                    # snlist = self._classes[cname]['sn']
                     # new ###
-                    ####assert snlist == list(self._dTypes[cname]['sn'])
+                    # assert snlist == list(self._dTypes[cname]['sn'])
                     snlist = list(self._dTypes[cname]['sn'])
                     if is_MetaQ:
                         ret += self.meta_filter(q=query, typename=cname,
