@@ -1,37 +1,33 @@
 # -*- coding: utf-8 -*-
 out_tree = """tree out_tree
 ├── meta                                          <MetaData>
-│   └── listeners                               <ListnerSet>
+│   └── listeners                              <ListenerSet>
 ├── measurements                          <CompositeDataset>
 │   ├── meta                                      <MetaData>
-│   │   └── listeners                           <ListnerSet>
-│   ├── Time_Energy_Pos               <TableDataset> (5, 20)
+│   │   └── listeners                          <ListenerSet>
+│   ├── Time_Energy_Pos               <TableDataset> [5, 20]
 │   │   ├── meta                                  <MetaData>
-│   │   │   └── listeners                       <ListnerSet>
-│   │   ├── Time                              <Column> (20,)
-│   │   ├── Energy                            <Column> (20,)
-│   │   ├── Error                             <Column> (20,)
-│   │   ├── y                                 <Column> (20,)
-│   │   └── z                                 <Column> (20,)
-│   ├── calibration                  <ArrayDataset> (11, 11)
+│   │   │   └── listeners                      <ListenerSet>
+│   │   ├── Time                               <Column> [20]
+│   │   ├── Energy                             <Column> [20]
+│   │   ├── Error                              <Column> [20]
+│   │   ├── y                                  <Column> [20]
+│   │   └── z                                  <Column> [20]
+│   ├── calibration                  <ArrayDataset> [11, 11]
 │   └── dset                                           <str>
-├── Environment Temperature              <ArrayDataset> (7,)
-├── Browse                               <image/png> (5976,)
+├── Environment Temperature               <ArrayDataset> [7]
+├── Browse                                <image/png> [5976]
 ├── refs                                      <RefContainer>
 │   ├── a_reference                             <ProductRef>
 │   │   └── urnobj                                     <Urn>
 │   │       └── urn                                    <str>
 │   └── a_different_name                        <ProductRef>
-├── history                                        <History>
+├── history                            <TableDataset> [2, 0]
 │   ├── meta                                      <MetaData>
-│   │   └── listeners                           <ListnerSet>
-│   ├── args                             <ArrayDataset> (0,)
-│   └── kw_args                        <TableDataset> (2, 0)
-│       ├── meta                                  <MetaData>
-│       │   └── listeners                       <ListnerSet>
-│       ├── name                               <Column> (0,)
-│       └── value                              <Column> (0,)
-└── listeners                                   <ListnerSet>
+│   │   └── listeners                          <ListenerSet>
+│   ├── name                                    <Column> [0]
+│   └── reference                               <Column> [0]
+└── listeners                                  <ListenerSet>
 ├── meta                                          <MetaData>
 │   ├── description                                 <string>
 │   │   ├── description                                <str>
@@ -100,11 +96,11 @@ out_tree = """tree out_tree
 │   │   │       └── 0                                 <list>
 │   │   ├── unit                                       <str>
 │   │   └── typecode                              <NoneType>
-│   └── listeners                               <ListnerSet>
+│   └── listeners                              <ListenerSet>
 ├── measurements                          <CompositeDataset>
 │   ├── meta                                      <MetaData>
-│   │   └── listeners                           <ListnerSet>
-│   ├── Time_Energy_Pos               <TableDataset> (5, 20)
+│   │   └── listeners                          <ListenerSet>
+│   ├── Time_Energy_Pos               <TableDataset> [5, 20]
 │   │   ├── meta                                  <MetaData>
 │   │   │   ├── description                         <string>
 │   │   │   │   ├── description                        <str>
@@ -112,13 +108,14 @@ out_tree = """tree out_tree
 │   │   │   │   ├── value                              <str>
 │   │   │   │   ├── valid                         <NoneType>
 │   │   │   │   └── typecode                           <str>
-│   │   │   ├── shape                                <tuple>
+│   │   │   ├── shape                                 <list>
 │   │   │   │   ├── description                        <str>
 │   │   │   │   ├── type                               <str>
-│   │   │   │   ├── default                          <tuple>
-│   │   │   │   ├── value                            <tuple>
+│   │   │   │   ├── default                           <list>
+│   │   │   │   ├── value                             <list>
 │   │   │   │   ├── valid                         <NoneType>
-│   │   │   │   └── listeners                   <ListnerSet>
+│   │   │   │   ├── unit                               <str>
+│   │   │   │   └── typecode                           <str>
 │   │   │   ├── type                                <string>
 │   │   │   │   ├── description                        <str>
 │   │   │   │   ├── default                            <str>
@@ -137,62 +134,59 @@ out_tree = """tree out_tree
 │   │   │   │   ├── value                              <str>
 │   │   │   │   ├── valid                         <NoneType>
 │   │   │   │   └── typecode                           <str>
-│   │   │   └── listeners                       <ListnerSet>
-│   │   ├── Time                              <Column> (20,)
-│   │   ├── Energy                            <Column> (20,)
-│   │   ├── Error                             <Column> (20,)
-│   │   ├── y                                 <Column> (20,)
-│   │   └── z                                 <Column> (20,)
-│   ├── calibration                  <ArrayDataset> (11, 11)
+│   │   │   └── listeners                      <ListenerSet>
+│   │   ├── Time                               <Column> [20]
+│   │   ├── Energy                             <Column> [20]
+│   │   ├── Error                              <Column> [20]
+│   │   ├── y                                  <Column> [20]
+│   │   └── z                                  <Column> [20]
+│   ├── calibration                  <ArrayDataset> [11, 11]
 │   └── dset                                           <str>
-├── Environment Temperature              <ArrayDataset> (7,)
-├── Browse                               <image/png> (5976,)
+├── Environment Temperature               <ArrayDataset> [7]
+├── Browse                                <image/png> [5976]
 ├── refs                                      <RefContainer>
 │   ├── a_reference                             <ProductRef>
 │   │   └── urnobj                                     <Urn>
 │   │       └── urn                                    <str>
 │   └── a_different_name                        <ProductRef>
-├── history                                        <History>
+├── history                            <TableDataset> [2, 0]
 │   ├── meta                                      <MetaData>
-│   │   └── listeners                           <ListnerSet>
-│   ├── args                             <ArrayDataset> (0,)
-│   └── kw_args                        <TableDataset> (2, 0)
-│       ├── meta                                  <MetaData>
-│       │   ├── description                         <string>
-│       │   │   ├── description                        <str>
-│       │   │   ├── default                            <str>
-│       │   │   ├── value                              <str>
-│       │   │   ├── valid                         <NoneType>
-│       │   │   └── typecode                           <str>
-│       │   ├── shape                                <tuple>
-│       │   │   ├── description                        <str>
-│       │   │   ├── type                               <str>
-│       │   │   ├── default                          <tuple>
-│       │   │   ├── value                            <tuple>
-│       │   │   ├── valid                         <NoneType>
-│       │   │   └── listeners                   <ListnerSet>
-│       │   ├── type                                <string>
-│       │   │   ├── description                        <str>
-│       │   │   ├── default                            <str>
-│       │   │   ├── value                              <str>
-│       │   │   ├── valid                         <NoneType>
-│       │   │   └── typecode                           <str>
-│       │   ├── version                             <string>
-│       │   │   ├── description                        <str>
-│       │   │   ├── default                            <str>
-│       │   │   ├── value                              <str>
-│       │   │   ├── valid                         <NoneType>
-│       │   │   └── typecode                           <str>
-│       │   ├── FORMATV                             <string>
-│       │   │   ├── description                        <str>
-│       │   │   ├── default                            <str>
-│       │   │   ├── value                              <str>
-│       │   │   ├── valid                         <NoneType>
-│       │   │   └── typecode                           <str>
-│       │   └── listeners                       <ListnerSet>
-│       ├── name                               <Column> (0,)
-│       └── value                              <Column> (0,)
-└── listeners                                   <ListnerSet>
+│   │   ├── description                             <string>
+│   │   │   ├── description                            <str>
+│   │   │   ├── default                                <str>
+│   │   │   ├── value                                  <str>
+│   │   │   ├── valid                             <NoneType>
+│   │   │   └── typecode                               <str>
+│   │   ├── shape                                     <list>
+│   │   │   ├── description                            <str>
+│   │   │   ├── type                                   <str>
+│   │   │   ├── default                               <list>
+│   │   │   ├── value                                 <list>
+│   │   │   ├── valid                             <NoneType>
+│   │   │   ├── unit                                   <str>
+│   │   │   └── typecode                               <str>
+│   │   ├── type                                    <string>
+│   │   │   ├── description                            <str>
+│   │   │   ├── default                                <str>
+│   │   │   ├── value                                  <str>
+│   │   │   ├── valid                             <NoneType>
+│   │   │   └── typecode                               <str>
+│   │   ├── version                                 <string>
+│   │   │   ├── description                            <str>
+│   │   │   ├── default                                <str>
+│   │   │   ├── value                                  <str>
+│   │   │   ├── valid                             <NoneType>
+│   │   │   └── typecode                               <str>
+│   │   ├── FORMATV                                 <string>
+│   │   │   ├── description                            <str>
+│   │   │   ├── default                                <str>
+│   │   │   ├── value                                  <str>
+│   │   │   ├── valid                             <NoneType>
+│   │   │   └── typecode                               <str>
+│   │   └── listeners                          <ListenerSet>
+│   ├── name                                    <Column> [0]
+│   └── reference                               <Column> [0]
+└── listeners                                  <ListenerSet>
 |__ meta                                          <MetaData>
 |   |__ description                                 <string>
 |   |   |__ description                                <str>
@@ -261,11 +255,11 @@ out_tree = """tree out_tree
 |   |   |       \__ 0                                 <list>
 |   |   |__ unit                                       <str>
 |   |   \__ typecode                              <NoneType>
-|   \__ listeners                               <ListnerSet>
+|   \__ listeners                              <ListenerSet>
 |__ measurements                          <CompositeDataset>
 |   |__ meta                                      <MetaData>
-|   |   \__ listeners                           <ListnerSet>
-|   |__ Time_Energy_Pos               <TableDataset> (5, 20)
+|   |   \__ listeners                          <ListenerSet>
+|   |__ Time_Energy_Pos               <TableDataset> [5, 20]
 |   |   |__ meta                                  <MetaData>
 |   |   |   |__ description                         <string>
 |   |   |   |   |__ description                        <str>
@@ -273,13 +267,14 @@ out_tree = """tree out_tree
 |   |   |   |   |__ value                              <str>
 |   |   |   |   |__ valid                         <NoneType>
 |   |   |   |   \__ typecode                           <str>
-|   |   |   |__ shape                                <tuple>
+|   |   |   |__ shape                                 <list>
 |   |   |   |   |__ description                        <str>
 |   |   |   |   |__ type                               <str>
-|   |   |   |   |__ default                          <tuple>
-|   |   |   |   |__ value                            <tuple>
+|   |   |   |   |__ default                           <list>
+|   |   |   |   |__ value                             <list>
 |   |   |   |   |__ valid                         <NoneType>
-|   |   |   |   \__ listeners                   <ListnerSet>
+|   |   |   |   |__ unit                               <str>
+|   |   |   |   \__ typecode                           <str>
 |   |   |   |__ type                                <string>
 |   |   |   |   |__ description                        <str>
 |   |   |   |   |__ default                            <str>
@@ -298,59 +293,56 @@ out_tree = """tree out_tree
 |   |   |   |   |__ value                              <str>
 |   |   |   |   |__ valid                         <NoneType>
 |   |   |   |   \__ typecode                           <str>
-|   |   |   \__ listeners                       <ListnerSet>
-|   |   |__ Time                              <Column> (20,)
-|   |   |__ Energy                            <Column> (20,)
-|   |   |__ Error                             <Column> (20,)
-|   |   |__ y                                 <Column> (20,)
-|   |   \__ z                                 <Column> (20,)
-|   |__ calibration                  <ArrayDataset> (11, 11)
+|   |   |   \__ listeners                      <ListenerSet>
+|   |   |__ Time                               <Column> [20]
+|   |   |__ Energy                             <Column> [20]
+|   |   |__ Error                              <Column> [20]
+|   |   |__ y                                  <Column> [20]
+|   |   \__ z                                  <Column> [20]
+|   |__ calibration                  <ArrayDataset> [11, 11]
 |   \__ dset                                           <str>
-|__ Environment Temperature              <ArrayDataset> (7,)
-|__ Browse                               <image/png> (5976,)
+|__ Environment Temperature               <ArrayDataset> [7]
+|__ Browse                                <image/png> [5976]
 |__ refs                                      <RefContainer>
 |   |__ a_reference                             <ProductRef>
 |   |   \__ urnobj                                     <Urn>
 |   |       \__ urn                                    <str>
 |   \__ a_different_name                        <ProductRef>
-|__ history                                        <History>
+|__ history                            <TableDataset> [2, 0]
 |   |__ meta                                      <MetaData>
-|   |   \__ listeners                           <ListnerSet>
-|   |__ args                             <ArrayDataset> (0,)
-|   \__ kw_args                        <TableDataset> (2, 0)
-|       |__ meta                                  <MetaData>
-|       |   |__ description                         <string>
-|       |   |   |__ description                        <str>
-|       |   |   |__ default                            <str>
-|       |   |   |__ value                              <str>
-|       |   |   |__ valid                         <NoneType>
-|       |   |   \__ typecode                           <str>
-|       |   |__ shape                                <tuple>
-|       |   |   |__ description                        <str>
-|       |   |   |__ type                               <str>
-|       |   |   |__ default                          <tuple>
-|       |   |   |__ value                            <tuple>
-|       |   |   |__ valid                         <NoneType>
-|       |   |   \__ listeners                   <ListnerSet>
-|       |   |__ type                                <string>
-|       |   |   |__ description                        <str>
-|       |   |   |__ default                            <str>
-|       |   |   |__ value                              <str>
-|       |   |   |__ valid                         <NoneType>
-|       |   |   \__ typecode                           <str>
-|       |   |__ version                             <string>
-|       |   |   |__ description                        <str>
-|       |   |   |__ default                            <str>
-|       |   |   |__ value                              <str>
-|       |   |   |__ valid                         <NoneType>
-|       |   |   \__ typecode                           <str>
-|       |   |__ FORMATV                             <string>
-|       |   |   |__ description                        <str>
-|       |   |   |__ default                            <str>
-|       |   |   |__ value                              <str>
-|       |   |   |__ valid                         <NoneType>
-|       |   |   \__ typecode                           <str>
-|       |   \__ listeners                       <ListnerSet>
-|       |__ name                               <Column> (0,)
-|       \__ value                              <Column> (0,)
-\__ listeners                                   <ListnerSet>"""
+|   |   |__ description                             <string>
+|   |   |   |__ description                            <str>
+|   |   |   |__ default                                <str>
+|   |   |   |__ value                                  <str>
+|   |   |   |__ valid                             <NoneType>
+|   |   |   \__ typecode                               <str>
+|   |   |__ shape                                     <list>
+|   |   |   |__ description                            <str>
+|   |   |   |__ type                                   <str>
+|   |   |   |__ default                               <list>
+|   |   |   |__ value                                 <list>
+|   |   |   |__ valid                             <NoneType>
+|   |   |   |__ unit                                   <str>
+|   |   |   \__ typecode                               <str>
+|   |   |__ type                                    <string>
+|   |   |   |__ description                            <str>
+|   |   |   |__ default                                <str>
+|   |   |   |__ value                                  <str>
+|   |   |   |__ valid                             <NoneType>
+|   |   |   \__ typecode                               <str>
+|   |   |__ version                                 <string>
+|   |   |   |__ description                            <str>
+|   |   |   |__ default                                <str>
+|   |   |   |__ value                                  <str>
+|   |   |   |__ valid                             <NoneType>
+|   |   |   \__ typecode                               <str>
+|   |   |__ FORMATV                                 <string>
+|   |   |   |__ description                            <str>
+|   |   |   |__ default                                <str>
+|   |   |   |__ value                                  <str>
+|   |   |   |__ valid                             <NoneType>
+|   |   |   \__ typecode                               <str>
+|   |   \__ listeners                          <ListenerSet>
+|   |__ name                                    <Column> [0]
+|   \__ reference                               <Column> [0]
+\__ listeners                                  <ListenerSet>"""
