@@ -22,7 +22,7 @@ from fdi.dataset.metadata import MetaData, Parameter
 from fdi.dataset.finetime import FineTime1
 from fdi.dataset.testproducts import TP
 from fdi.utils.checkjson import checkjson
-from fdi.pns.fdi_requests import save_to_server, read_from_server, delete_from_server
+from fdi.pns.fdi_requests import save_to_server, read_from_server
 
 # from flask import request as
 import requests
@@ -111,7 +111,12 @@ def test_UrnUtils():
     urn = 'urn:' + b2 + ':' + r  # urn:name:fdi.dataset.Product:43
     urn1 = 'urn:' + b2 + ':' + a4+':'+str(a5-1)
     # utils
+    assert parseUrn(None) == (None, None, None)
     assert parseUrn(urn) == (b2, a4, a5)
+    assert parseUrn([urn, urn]) == (b2, a4, [a5, a5])
+    assert parseUrn(urn) == (b2, a4, a5)
+    assert parseUrn([urn, f'urn:{b2+"a"}:{a4+"b"}:{a5+3}']) == \
+        ([b2, b2+"a"], [a4, a4+"b"], [a5, a5+3])
     assert UrnUtils.isUrn(urn)
     assert UrnUtils.getProductId(urn) == a5
     assert UrnUtils.getPoolId(urn) == b2
@@ -345,8 +350,11 @@ def test_PoolManager():
     assert pm.remove(defaultpoolName) == 0
 
     # http pool gets registered
-    with pytest.raises(NewConnectionError):
-        ph = pm.getPool(poolurl='http://h.edu/foo')
+    try:
+        with pytest.raises(ConnectionError):
+            ph = pm.getPool(poolurl='http://h.edu/foo')
+    except NewConnectionError:
+        pass
     assert not PoolManager.isLoaded('foo')
     with pytest.raises(KeyError):
         assert PoolManager.remove('foo') == 1
@@ -602,12 +610,11 @@ def check_prodStorage_func_for_pool(thepoolname, thepoolurl, *args):
         init_sn, init_count, pinfo = getCurrSnCount(csdb, pcq)
         init_sn_m, init_count_m, _ = getCurrSnCount(pinfo, mcq)
         logger.debug('1...', init_count, init_sn, init_count_m, init_sn_m)
-
     # save
     ref = ps.save(x)
     s0, s1 = tuple(ref.urn.rsplit(':', 1))
     assert s0 == 'urn:' + thepoolname + ':' + pcq
-    # not saving thie one
+    # not saving this one
     # ref_m = ps.save(y)
     init_count, init_count_m = 0, 0
     if is_csdb:
@@ -803,6 +810,36 @@ def test_LocalPool():
     assert deepcmp(p1._dTypes, p2._dTypes) is None
     assert deepcmp(p1._dTags, p2._dTags) is None
 
+    # remove till empty
+    ps2.save(x, tag='ttag')
+    urns = ps2.getUrnFromTag('ttag')
+    assert len(urns) == 2
+    for u in urns:
+        p2.remove(u)
+    assert len(ps2.getUrnFromTag('ttag')) == 0
+
+    # remove multiple sn
+    ps2.save(x, tag='mtag')
+    ps2.save(x, tag='mtag')
+    urns = ps2.getUrnFromTag('mtag')
+    pool, dtype, sns = parseUrn(urns)
+    assert pool == cpn
+    assert dtype == 'fdi.dataset.product.Product'
+    assert len(sns) == 2
+    p2.remove(resourcetype=dtype, index=sns)
+    assert len(ps2.getUrnFromTag('mtag')) == 0
+
+    # remove multiple sn ASYNCHRONOUSLY
+    ps2.save(x, tag='mtag')
+    ps2.save(x, tag='mtag')
+    urns = ps2.getUrnFromTag('mtag')
+    pool, dtype, sns = parseUrn(urns)
+    assert pool == cpn
+    assert dtype == 'fdi.dataset.product.Product'
+    assert len(sns) == 2
+    p2.remove(resourcetype=dtype, index=sns, asyn=True)
+    assert len(ps2.getUrnFromTag('mtag')) == 0
+
     backup_restore(ps)
 
 
@@ -1117,7 +1154,7 @@ def test_query_http(server):
     aburl = aburl.rstrip('/')
     cleanup()
     lpath = '/tmp'
-    ### TODO: http
+    # TODO: http
     doquery(aburl, aburl)
     doquery('file://'+lpath, aburl)
     doquery('mem://'+lpath, aburl)
